# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: quality_verification_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import shared_types_pb2 as shared__types__pb2
import shared_qa_pb2 as shared__qa__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"quality_verification_service.proto\x12%ProSuite.Microservices.Definitions.QA\x1a\x12shared_types.proto\x1a\x0fshared_qa.proto\"\xa3\x03\n\x13VerificationRequest\x12K\n\x0cwork_context\x18\x01 \x01(\x0b\x32\x35.ProSuite.Microservices.Definitions.QA.WorkContextMsg\x12U\n\rspecification\x18\x02 \x01(\x0b\x32>.ProSuite.Microservices.Definitions.QA.QualitySpecificationMsg\x12T\n\nparameters\x18\x03 \x01(\x0b\x32@.ProSuite.Microservices.Definitions.QA.VerificationParametersMsg\x12I\n\x08\x66\x65\x61tures\x18\x05 \x03(\x0b\x32\x37.ProSuite.Microservices.Definitions.Shared.GdbObjectMsg\x12\x11\n\tuser_name\x18\x06 \x01(\t\x12\x1f\n\x17max_parallel_processing\x18\x07 \x01(\x05\x12\x13\n\x0b\x65nvironment\x18\x08 \x01(\t\"\xe6\x01\n\x17\x44\x61taVerificationRequest\x12K\n\x07request\x18\x01 \x01(\x0b\x32:.ProSuite.Microservices.Definitions.QA.VerificationRequest\x12<\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32..ProSuite.Microservices.Definitions.QA.GdbData\x12@\n\x06schema\x18\x03 \x01(\x0b\x32\x30.ProSuite.Microservices.Definitions.QA.SchemaMsg\"\x81\x03\n\x1dStandaloneVerificationRequest\x12^\n\x11xml_specification\x18\x01 \x01(\x0b\x32\x41.ProSuite.Microservices.Definitions.QA.XmlQualitySpecificationMsgH\x00\x12l\n\x1c\x63ondition_list_specification\x18\x04 \x01(\x0b\x32\x44.ProSuite.Microservices.Definitions.QA.ConditionListSpecificationMsgH\x00\x12T\n\nparameters\x18\x02 \x01(\x0b\x32@.ProSuite.Microservices.Definitions.QA.VerificationParametersMsg\x12\x18\n\x10output_directory\x18\x03 \x01(\t\x12\x11\n\tuser_name\x18\x06 \x01(\tB\x0f\n\rspecification\"\xca\x03\n\x14VerificationResponse\x12\x1b\n\x13service_call_status\x18\x01 \x01(\x05\x12P\n\x08progress\x18\x02 \x01(\x0b\x32>.ProSuite.Microservices.Definitions.QA.VerificationProgressMsg\x12?\n\x06issues\x18\x03 \x03(\x0b\x32/.ProSuite.Microservices.Definitions.QA.IssueMsg\x12[\n\x14quality_verification\x18\x04 \x01(\x0b\x32=.ProSuite.Microservices.Definitions.QA.QualityVerificationMsg\x12O\n\x12verified_perimeter\x18\x05 \x01(\x0b\x32\x33.ProSuite.Microservices.Definitions.Shared.ShapeMsg\x12T\n\x13obsolete_exceptions\x18\x06 \x03(\x0b\x32\x37.ProSuite.Microservices.Definitions.Shared.GdbObjRefMsg\"\x81\x02\n\x18\x44\x61taVerificationResponse\x12M\n\x08response\x18\x01 \x01(\x0b\x32;.ProSuite.Microservices.Definitions.QA.VerificationResponse\x12H\n\x0c\x64\x61ta_request\x18\x02 \x01(\x0b\x32\x32.ProSuite.Microservices.Definitions.QA.DataRequest\x12L\n\x0eschema_request\x18\x03 \x01(\x0b\x32\x34.ProSuite.Microservices.Definitions.QA.SchemaRequest\"\xbe\x01\n\x1eStandaloneVerificationResponse\x12\x1b\n\x13service_call_status\x18\x01 \x01(\x05\x12>\n\x07message\x18\x02 \x01(\x0b\x32-.ProSuite.Microservices.Definitions.QA.LogMsg\x12?\n\x06issues\x18\x03 \x03(\x0b\x32/.ProSuite.Microservices.Definitions.QA.IssueMsg2\xee\x03\n\x17QualityVerificationGrpc\x12\x8c\x01\n\rVerifyQuality\x12:.ProSuite.Microservices.Definitions.QA.VerificationRequest\x1a;.ProSuite.Microservices.Definitions.QA.VerificationResponse\"\x00\x30\x01\x12\x9a\x01\n\x11VerifyDataQuality\x12>.ProSuite.Microservices.Definitions.QA.DataVerificationRequest\x1a?.ProSuite.Microservices.Definitions.QA.DataVerificationResponse\"\x00(\x01\x30\x01\x12\xa6\x01\n\x13VerifyStandaloneXml\x12\x44.ProSuite.Microservices.Definitions.QA.StandaloneVerificationRequest\x1a\x45.ProSuite.Microservices.Definitions.QA.StandaloneVerificationResponse\"\x00\x30\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'quality_verification_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _VERIFICATIONREQUEST._serialized_start=115
  _VERIFICATIONREQUEST._serialized_end=534
  _DATAVERIFICATIONREQUEST._serialized_start=537
  _DATAVERIFICATIONREQUEST._serialized_end=767
  _STANDALONEVERIFICATIONREQUEST._serialized_start=770
  _STANDALONEVERIFICATIONREQUEST._serialized_end=1155
  _VERIFICATIONRESPONSE._serialized_start=1158
  _VERIFICATIONRESPONSE._serialized_end=1616
  _DATAVERIFICATIONRESPONSE._serialized_start=1619
  _DATAVERIFICATIONRESPONSE._serialized_end=1876
  _STANDALONEVERIFICATIONRESPONSE._serialized_start=1879
  _STANDALONEVERIFICATIONRESPONSE._serialized_end=2069
  _QUALITYVERIFICATIONGRPC._serialized_start=2072
  _QUALITYVERIFICATIONGRPC._serialized_end=2566
# @@protoc_insertion_point(module_scope)
