# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: shared_types.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12shared_types.proto\x12)ProSuite.Microservices.Definitions.Shared\"\x15\n\x04UUID\x12\r\n\x05value\x18\x01 \x01(\x0c\"I\n\x0b\x45nvelopeMsg\x12\r\n\x05x_min\x18\x01 \x01(\x01\x12\r\n\x05y_min\x18\x02 \x01(\x01\x12\r\n\x05x_max\x18\x03 \x01(\x01\x12\r\n\x05y_max\x18\x04 \x01(\x01\"\xe0\x01\n\x08ShapeMsg\x12\x14\n\nesri_shape\x18\x01 \x01(\x0cH\x00\x12\r\n\x03wkb\x18\x02 \x01(\x0cH\x00\x12J\n\x08\x65nvelope\x18\x03 \x01(\x0b\x32\x36.ProSuite.Microservices.Definitions.Shared.EnvelopeMsgH\x00\x12Y\n\x11spatial_reference\x18\x04 \x01(\x0b\x32>.ProSuite.Microservices.Definitions.Shared.SpatialReferenceMsgB\x08\n\x06\x66ormat\"\xa6\x02\n\x0e\x41ttributeValue\x12\x11\n\x07\x64\x62_null\x18\x01 \x01(\x08H\x00\x12\x19\n\x0fshort_int_value\x18\x02 \x01(\x05H\x00\x12\x18\n\x0elong_int_value\x18\x03 \x01(\x05H\x00\x12\x15\n\x0b\x66loat_value\x18\x04 \x01(\x02H\x00\x12\x16\n\x0c\x64ouble_value\x18\x05 \x01(\x01H\x00\x12\x16\n\x0cstring_value\x18\x06 \x01(\tH\x00\x12\x1f\n\x15\x64\x61te_time_ticks_value\x18\x07 \x01(\x03H\x00\x12\x45\n\nuuid_value\x18\x08 \x01(\x0b\x32/.ProSuite.Microservices.Definitions.Shared.UUIDH\x00\x12\x14\n\nblob_value\x18\t \x01(\x0cH\x00\x42\x07\n\x05value\"\xc6\x01\n\x0cGdbObjectMsg\x12\x11\n\tobject_id\x18\x01 \x01(\x03\x12\x14\n\x0c\x63lass_handle\x18\x02 \x01(\x03\x12I\n\x06values\x18\x03 \x03(\x0b\x32\x39.ProSuite.Microservices.Definitions.Shared.AttributeValue\x12\x42\n\x05Shape\x18\x04 \x01(\x0b\x32\x33.ProSuite.Microservices.Definitions.Shared.ShapeMsg\"7\n\x0cGdbObjRefMsg\x12\x14\n\x0c\x63lass_handle\x18\x01 \x01(\x03\x12\x11\n\tobject_id\x18\x02 \x01(\x03\"\x94\x02\n\x0eObjectClassMsg\x12\x14\n\x0c\x63lass_handle\x18\x01 \x01(\x03\x12\x18\n\x10workspace_handle\x18\x02 \x01(\x03\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\r\n\x05\x61lias\x18\x04 \x01(\t\x12\x15\n\rgeometry_type\x18\x05 \x01(\x05\x12Y\n\x11spatial_reference\x18\x06 \x01(\x0b\x32>.ProSuite.Microservices.Definitions.Shared.SpatialReferenceMsg\x12\x43\n\x06\x66ields\x18\x07 \x03(\x0b\x32\x33.ProSuite.Microservices.Definitions.Shared.FieldMsg\"\xd9\x02\n\x0cWorkspaceMsg\x12\x18\n\x10workspace_handle\x18\x01 \x01(\x03\x12\x19\n\x11workspace_db_type\x18\x02 \x01(\x05\x12\x0c\n\x04path\x18\x03 \x01(\t\x12\x14\n\x0cversion_name\x18\x04 \x01(\t\x12\x1c\n\x14\x64\x65\x66\x61ult_version_name\x18\x05 \x01(\t\x12#\n\x1b\x64\x65\x66\x61ult_version_description\x18\x06 \x01(\t\x12&\n\x1e\x64\x65\x66\x61ult_version_creation_ticks\x18\x07 \x01(\x03\x12Y\n\x15\x63onnection_properties\x18\x08 \x03(\x0b\x32:.ProSuite.Microservices.Definitions.Shared.KeyValuePairMsg\x12*\n\"default_version_modification_ticks\x18\t \x01(\x03\"-\n\x0fKeyValuePairMsg\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\xab\x01\n\x08\x46ieldMsg\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\nalias_name\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\x05\x12\x0e\n\x06length\x18\x04 \x01(\x05\x12\x13\n\x0b\x64omain_name\x18\x05 \x01(\t\x12\r\n\x05scale\x18\x06 \x01(\x05\x12\x11\n\tprecision\x18\x07 \x01(\x05\x12\x13\n\x0bis_nullable\x18\x08 \x01(\x08\x12\x13\n\x0bis_editable\x18\t \x01(\x08\"\x88\x01\n\x13SpatialReferenceMsg\x12$\n\x1aspatial_reference_esri_xml\x18\x01 \x01(\tH\x00\x12\x1f\n\x15spatial_reference_wkt\x18\x02 \x01(\tH\x00\x12 \n\x16spatial_reference_wkid\x18\x03 \x01(\x05H\x00\x42\x08\n\x06\x66ormat\"\xae\x02\n\x0fResultObjectMsg\x12I\n\x06update\x18\x01 \x01(\x0b\x32\x37.ProSuite.Microservices.Definitions.Shared.GdbObjectMsgH\x00\x12N\n\x06insert\x18\x02 \x01(\x0b\x32<.ProSuite.Microservices.Definitions.Shared.InsertedObjectMsgH\x00\x12I\n\x06\x64\x65lete\x18\x03 \x01(\x0b\x32\x37.ProSuite.Microservices.Definitions.Shared.GdbObjRefMsgH\x00\x12\x15\n\rnotifications\x18\x04 \x03(\t\x12\x13\n\x0bhas_warning\x18\x05 \x01(\x08\x42\t\n\x07\x66\x65\x61ture\"\xba\x01\n\x11InsertedObjectMsg\x12P\n\x0finserted_object\x18\x01 \x01(\x0b\x32\x37.ProSuite.Microservices.Definitions.Shared.GdbObjectMsg\x12S\n\x12original_reference\x18\x02 \x01(\x0b\x32\x37.ProSuite.Microservices.Definitions.Shared.GdbObjRefMsgb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'shared_types_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _UUID._serialized_start=65
  _UUID._serialized_end=86
  _ENVELOPEMSG._serialized_start=88
  _ENVELOPEMSG._serialized_end=161
  _SHAPEMSG._serialized_start=164
  _SHAPEMSG._serialized_end=388
  _ATTRIBUTEVALUE._serialized_start=391
  _ATTRIBUTEVALUE._serialized_end=685
  _GDBOBJECTMSG._serialized_start=688
  _GDBOBJECTMSG._serialized_end=886
  _GDBOBJREFMSG._serialized_start=888
  _GDBOBJREFMSG._serialized_end=943
  _OBJECTCLASSMSG._serialized_start=946
  _OBJECTCLASSMSG._serialized_end=1222
  _WORKSPACEMSG._serialized_start=1225
  _WORKSPACEMSG._serialized_end=1570
  _KEYVALUEPAIRMSG._serialized_start=1572
  _KEYVALUEPAIRMSG._serialized_end=1617
  _FIELDMSG._serialized_start=1620
  _FIELDMSG._serialized_end=1791
  _SPATIALREFERENCEMSG._serialized_start=1794
  _SPATIALREFERENCEMSG._serialized_end=1930
  _RESULTOBJECTMSG._serialized_start=1933
  _RESULTOBJECTMSG._serialized_end=2235
  _INSERTEDOBJECTMSG._serialized_start=2238
  _INSERTEDOBJECTMSG._serialized_end=2424
# @@protoc_insertion_point(module_scope)
